@@ -1,17 +1,19 @@
 #' @include dbi-driver.R
 NULL
 
-BigQueryConnection <- function(project,
-                               dataset,
-                               billing,
-                               page_size = 1e4,
-                               quiet = NA,
-                               use_legacy_sql = FALSE,
-                               bigint = c("integer", "integer64", "numeric", "character")) {
-
+BigQueryConnection <- function(
+  project,
+  dataset,
+  billing,
+  page_size = 1e4,
+  quiet = NA,
+  use_legacy_sql = FALSE,
+  bigint = c("integer", "integer64", "numeric", "character")
+) {
   connection_capture()
 
-  new("BigQueryConnection",
+  new(
+    "BigQueryConnection",
     project = project,
     dataset = dataset,
     billing = billing,
@@ -42,7 +44,8 @@ setClass(
 #' @inheritParams methods::show
 #' @export
 setMethod(
-  "show", "BigQueryConnection",
+  "show",
+  "BigQueryConnection",
   function(object) {
     cat_line("<BigQueryConnection>")
 
@@ -50,27 +53,35 @@ setMethod(
       cat_line("  Dataset: ", object@project, ".", object@dataset)
     }
     cat_line("  Billing: ", object@billing)
-
-  })
+  }
+)
 
 #' @rdname DBI
 #' @inheritParams DBI::dbIsValid
+#' @param dbObj An object inheriting from [DBI::DBIObject-class],
+#' i.e. [DBI::DBIDriver-class], [DBI::DBIConnection-class], or a [DBI::DBIResult-class].
+#' @param conn A [DBI::DBIConnection-class] object, as returned by
+#'   [DBI::dbConnect()].
 #' @export
 setMethod(
-  "dbIsValid", "BigQueryConnection",
+  "dbIsValid",
+  "BigQueryConnection",
   function(dbObj, ...) {
     TRUE
-  })
+  }
+)
 
 #' @rdname DBI
 #' @inheritParams DBI::dbDisconnect
 #' @export
 setMethod(
-  "dbDisconnect", "BigQueryConnection",
+  "dbDisconnect",
+  "BigQueryConnection",
   function(conn, ...) {
     on_connection_closed(conn)
     invisible(TRUE)
-  })
+  }
+)
 
 #' @rdname DBI
 #' @inheritParams DBI::dbSendQuery
@@ -86,27 +97,33 @@ setMethod(
 #' @rdname DBI
 #' @inheritParams DBI::dbSendQuery
 #' @export
-setMethod("dbExecute", c("BigQueryConnection", "character"), function(conn, statement, ...) {
-  ds <- if (!is.null(conn@dataset)) as_bq_dataset(conn)
+setMethod(
+  "dbExecute",
+  c("BigQueryConnection", "character"),
+  function(conn, statement, ...) {
+    ds <- if (!is.null(conn@dataset)) as_bq_dataset(conn)
 
-  job <- bq_perform_query(statement,
-    billing = conn@billing,
-    default_dataset = ds,
-    quiet = conn@quiet,
-    ...
-  )
-  bq_job_wait(job, quiet = conn@quiet)
+    job <- bq_perform_query(
+      statement,
+      billing = conn@billing,
+      default_dataset = ds,
+      quiet = conn@quiet,
+      ...
+    )
+    bq_job_wait(job, quiet = conn@quiet)
 
-  meta <- bq_job_meta(job, "statistics(query(numDmlAffectedRows))")
-  as.numeric(meta$statistics$query$numDmlAffectedRows %||% 0)
-})
+    meta <- bq_job_meta(job, "statistics(query(numDmlAffectedRows))")
+    as.numeric(meta$statistics$query$numDmlAffectedRows %||% 0)
+  }
+)
 
 
 #' @rdname DBI
 #' @inheritParams DBI::dbQuoteString
 #' @export
 setMethod(
-  "dbQuoteString", c("BigQueryConnection", "character"),
+  "dbQuoteString",
+  c("BigQueryConnection", "character"),
   function(conn, x, ...) {
     if (length(x) == 0) {
       return(SQL(character()))
@@ -115,21 +132,25 @@ setMethod(
     out <- encodeString(x, na.encode = FALSE, quote = "'")
     out[is.na(x)] <- "NULL"
     SQL(out, names = names(x))
-  })
+  }
+)
 
 #' @rdname DBI
 #' @export
 setMethod(
-  "dbQuoteString", c("BigQueryConnection", "SQL"),
+  "dbQuoteString",
+  c("BigQueryConnection", "SQL"),
   function(conn, x, ...) {
     x
-  })
+  }
+)
 
 #' @rdname DBI
 #' @inheritParams DBI::dbQuoteIdentifier
 #' @export
 setMethod(
-  "dbQuoteIdentifier", c("BigQueryConnection", "character"),
+  "dbQuoteIdentifier",
+  c("BigQueryConnection", "character"),
   function(conn, x, ...) {
     if (length(x) == 0) {
       return(SQL(character()))
@@ -146,12 +167,14 @@ setMethod(
     }
 
     SQL(out, names = names(x))
-  })
+  }
+)
 
 #' @rdname DBI
 #' @export
 setMethod(
-  "dbQuoteIdentifier", c("BigQueryConnection", "SQL"),
+  "dbQuoteIdentifier",
+  c("BigQueryConnection", "SQL"),
   function(conn, x, ...) {
     x
   }
@@ -160,7 +183,8 @@ setMethod(
 #' @rdname DBI
 #' @export
 setMethod(
-  "dbQuoteLiteral", c("BigQueryConnection", "logical"),
+  "dbQuoteLiteral",
+  c("BigQueryConnection", "logical"),
   function(conn, x, ...) {
     x <- as.character(x)
     x[is.na(x)] <- "NULL"
@@ -172,22 +196,24 @@ setMethod(
 #' @inheritParams DBI::dbDataType
 #' @export
 setMethod(
-  "dbDataType", "BigQueryConnection",
+  "dbDataType",
+  "BigQueryConnection",
   function(dbObj, obj, ...) {
     data_type(obj)
   }
 )
 
-dbWriteTable_bq <- function(conn,
-                            name,
-                            value,
-                            ...,
-                            overwrite = FALSE,
-                            append = FALSE,
-                            field.types = NULL,
-                            temporary = FALSE,
-                            row.names = NA) {
-
+dbWriteTable_bq <- function(
+  conn,
+  name,
+  value,
+  ...,
+  overwrite = FALSE,
+  append = FALSE,
+  field.types = NULL,
+  temporary = FALSE,
+  row.names = NA
+) {
   check_bool(overwrite)
   check_bool(append)
 
@@ -264,7 +290,9 @@ setMethod(
 dbAppendTable_bq <- function(conn, name, value, ..., row.names = NULL) {
   tb <- as_bq_table(conn, name)
 
-  bq_table_upload(tb, value,
+  bq_table_upload(
+    tb,
+    value,
     create_disposition = "CREATE_NEVER",
     write_disposition = "WRITE_APPEND",
     ...
@@ -277,22 +305,36 @@ dbAppendTable_bq <- function(conn, name, value, ..., row.names = NULL) {
 #' @inheritParams DBI::dbAppendTable
 #' @rdname DBI
 #' @export
-setMethod("dbAppendTable", c("BigQueryConnection", "character", "data.frame"), dbAppendTable_bq)
+setMethod(
+  "dbAppendTable",
+  c("BigQueryConnection", "character", "data.frame"),
+  dbAppendTable_bq
+)
 
 #' @rdname DBI
 #' @export
-setMethod("dbAppendTable", c("BigQueryConnection", "Id", "data.frame"), dbAppendTable_bq)
+setMethod(
+  "dbAppendTable",
+  c("BigQueryConnection", "Id", "data.frame"),
+  dbAppendTable_bq
+)
 
 #' @rdname DBI
 #' @export
-setMethod("dbAppendTable", c("BigQueryConnection", "AsIs", "data.frame"), dbAppendTable_bq)
+setMethod(
+  "dbAppendTable",
+  c("BigQueryConnection", "AsIs", "data.frame"),
+  dbAppendTable_bq
+)
 
-dbCreateTable_bq <- function(conn,
-                             name,
-                             fields,
-                             ...,
-                             row.names = NULL,
-                             temporary = FALSE) {
+dbCreateTable_bq <- function(
+  conn,
+  name,
+  fields,
+  ...,
+  row.names = NULL,
+  temporary = FALSE
+) {
   if (!identical(temporary, FALSE)) {
     cli::cli_abort(
       "{.code temporary = FALSE} not supported by bigrquery.",
@@ -318,7 +360,7 @@ setMethod("dbCreateTable", "BigQueryConnection", dbCreateTable_bq)
 
 dbReadTable_bq <- function(conn, name, ...) {
   tb <- as_bq_table(conn, name)
-  bq_table_download(tb, ...)
+  bq_table_download(tb, ..., api = "json")
 }
 
 #' @rdname DBI
@@ -338,7 +380,8 @@ setMethod("dbReadTable", c("BigQueryConnection", "AsIs"), dbReadTable_bq)
 #' @inheritParams DBI::dbListTables
 #' @export
 setMethod(
-  "dbListTables", "BigQueryConnection",
+  "dbListTables",
+  "BigQueryConnection",
   function(conn, ...) {
     if (is.null(conn@dataset)) {
       cli::cli_abort("Can't list tables without a connection `dataset`.")
@@ -347,7 +390,8 @@ setMethod(
 
     tbs <- bq_dataset_tables(ds, ...)
     map_chr(tbs, function(x) x$table)
-  })
+  }
+)
 
 dbExistsTable_bq <- function(conn, name, ...) {
   tb <- as_bq_table(conn, name)
@@ -356,7 +400,11 @@ dbExistsTable_bq <- function(conn, name, ...) {
 #' @inheritParams DBI::dbExistsTable
 #' @rdname DBI
 #' @export
-setMethod("dbExistsTable", c("BigQueryConnection", "character"), dbExistsTable_bq)
+setMethod(
+  "dbExistsTable",
+  c("BigQueryConnection", "character"),
+  dbExistsTable_bq
+)
 
 #' @rdname DBI
 #' @export
@@ -395,7 +443,11 @@ dbRemoveTable_bq <- function(conn, name, ...) {
 #' @inheritParams DBI::dbRemoveTable
 #' @rdname DBI
 #' @export
-setMethod("dbRemoveTable", c("BigQueryConnection", "character"), dbRemoveTable_bq)
+setMethod(
+  "dbRemoveTable",
+  c("BigQueryConnection", "character"),
+  dbRemoveTable_bq
+)
 
 #' @rdname DBI
 #' @export
@@ -410,7 +462,8 @@ setMethod("dbRemoveTable", c("BigQueryConnection", "AsIs"), dbRemoveTable_bq)
 #' @inheritParams DBI::dbGetInfo
 #' @export
 setMethod(
-  "dbGetInfo", "BigQueryConnection",
+  "dbGetInfo",
+  "BigQueryConnection",
   function(dbObj, ...) {
     list(
       db.version = NA,
@@ -419,37 +472,43 @@ setMethod(
       host = NA,
       port = NA
     )
-  })
+  }
+)
 
 #' @rdname DBI
 #' @inheritParams DBI::dbBegin
 #' @export
 setMethod(
-  "dbBegin", "BigQueryConnection",
+  "dbBegin",
+  "BigQueryConnection",
   function(conn, ...) {
     testthat::skip("Not yet implemented: dbBegin(Connection)")
-  })
+  }
+)
 
 #' @rdname DBI
 #' @inheritParams DBI::dbCommit
 #' @export
 setMethod(
-  "dbCommit", "BigQueryConnection",
+  "dbCommit",
+  "BigQueryConnection",
   function(conn, ...) {
     testthat::skip("Not yet implemented: dbCommit(Connection)")
-  })
+  }
+)
 
 #' @rdname DBI
 #' @inheritParams DBI::dbRollback
 #' @export
 setMethod(
-  "dbRollback", "BigQueryConnection",
+  "dbRollback",
+  "BigQueryConnection",
   function(conn, ...) {
     testthat::skip("Not yet implemented: dbRollback(Connection)")
-  })
+  }
+)
 # nocov end
 
-
 # Convert to bq objects ---------------------------------------------------
 
 #' @export
@@ -460,9 +519,14 @@ as_bq_dataset.BigQueryConnection <- function(x, ..., error_arg, error_call) {
 
 #' @export
 as_bq_table.BigQueryConnection <- function(x, name, ...) {
-  if (inherits(name, "dbplyr_table_path")) { # dbplyr 2.5.0
-    pieces <- utils::getFromNamespace("table_path_components", "dbplyr")(name, x)[[1]]
-  } else if (inherits(name, "dbplyr_table_ident")) { # dbplyr 2.4.0
+  if (inherits(name, "dbplyr_table_path")) {
+    # dbplyr 2.5.0
+    pieces <- utils::getFromNamespace("table_path_components", "dbplyr")(
+      name,
+      x
+    )[[1]]
+  } else if (inherits(name, "dbplyr_table_ident")) {
+    # dbplyr 2.4.0
     name <- unclass(name)
     pieces <- c(name$catalog, name$schema, name$table)
     pieces <- pieces[!is.na(pieces)]
@@ -489,7 +553,8 @@ as_bq_table.BigQueryConnection <- function(x, name, ...) {
     )
   }
 
-  switch(length(pieces),
+  switch(
+    length(pieces),
     bq_table(x@project, x@dataset, pieces[[1]]),
     bq_table(x@project, pieces[[1]], pieces[[2]]),
     bq_table(pieces[[1]], pieces[[2]], pieces[[3]])
