@@ -1,6 +1,6 @@
 .onLoad <- function(libname, pkgname) {
   .auth <<- gargle::init_AuthState(
-    package     = "bigrquery",
+    package = "bigrquery",
     auth_active = TRUE
   )
 
@@ -26,7 +26,9 @@
     bigrquery.page.size = 1e4
   )
   toset <- !(names(defaults) %in% names(op))
-  if (any(toset)) options(defaults[toset])
+  if (any(toset)) {
+    options(defaults[toset])
+  }
 
   invisible()
 }
